@@ -9,15 +9,13 @@ cmake \
 	${SRC_DIR} \
 	${CMAKE_ARGS} \
 	-DCMAKE_BUILD_TYPE:STRING=Release \
-	-DBUILD_TESTS:BOOL=TRUE \
-	-DEXTERNAL_PICOJSON:BOOL=TRUE \
+	-DJWT_BUILD_EXAMPLES:BOOL=FALSE \
+	-DJWT_BUILD_TESTS:BOOL=FALSE \
+	-DJWT_EXTERNAL_PICOJSON:BOOL=TRUE \
 ;
 
 # build
 cmake --build . --verbose --parallel ${CPU_COUNT}
 
-# test
-./tests/jwt-cpp-test
-
 # install
 cmake --build . --verbose --parallel ${CPU_COUNT} --target install
